--
-- Metadata for invoking parameter callbacks.
--
-- @author Lee Denison (lee@xarg.co.uk)

create or replace function dtype_proc__create (varchar)
returns integer as '
declare
  p_name                alias for $1;  
begin

    insert into dtype_procs (
        name
    )
    values (
        p_name
    );

    return 0; 
end;' language 'plpgsql';

create or replace function dtype_proc__delete (varchar)
returns integer as '
declare
  p_name                alias for $1;  
  v_param               RECORD;
begin
  
    -- delete all parameters
    for v_param in select *
                   from dtype_proc_params
                   where proc = p_name
    loop
        perform dtype_proc_param__delete(v_param.param_id);
    end loop;

    delete from dtype_procs where name = p_name; 

    return 0; 
end;' language 'plpgsql';

create or replace function dtype_proc_param__create (integer,varchar,varchar,varchar,boolean,varchar)
returns integer as '
declare
  p_param_id            alias for $1;  
  p_proc                alias for $2;  
  p_name                alias for $3;  
  p_param_type          alias for $4;  
  p_is_required         alias for $5;  -- default ''f''
  p_default_value       alias for $6;
  v_param_id            dtype_proc_params.param_id%TYPE;
begin

    select coalesce(p_param_id, nextval(''t_dtype_seq'')) into v_param_id;
  
    insert into dtype_proc_params (
        param_id,
        proc,
        name,
        param_type,
        is_required,
        default_value
    )
    values (
        v_param_id,
        p_proc,
        p_name,
        p_param_type,
        p_is_required,
        p_default_value
    );

    return v_param_id; 
end;' language 'plpgsql';

create or replace function dtype_proc_param__delete (integer)
returns integer as '
declare
  p_param_id           alias for $1;  
  v_value              RECORD;
begin
  
    -- delete all parameter values
    for v_value in select *
                   from dtype_proc_param_values
                   where param_id = p_param_id
    loop
        perform dtype_proc_param_value__delete(v_value.param_id, v_value.values_id);
    end loop;

    delete from dtype_proc_params where param_id = v_param_id;

    return 0; 
end;' language 'plpgsql';


create or replace function dtype_proc_param_value__create (integer,integer,integer,varchar,varchar)
returns integer as '
declare
  p_value_id            alias for $1;  
  p_call_id             alias for $2;  
  p_param_id            alias for $3;  
  p_param_source        alias for $4;  
  p_value               alias for $5;  
  v_value_id            dtype_proc_param_values.value_id%TYPE;
begin
    select coalesce(p_value_id, nextval(''t_dtype_seq'')) into v_value_id;

    insert into dtype_proc_param_values (
        value_id,
        call_id,
        param_id,
        param_source,
        value
    )
    values (
        v_value_id,
        p_call_id,
        p_param_id,
        p_param_source,
        p_value
    );

    return v_value_id; 
end;' language 'plpgsql';

create or replace function dtype_proc_param_value__delete (integer,integer)
returns integer as '
declare
  p_call_id             alias for $1;  
  p_param_id            alias for $2;  
begin
    delete from dtype_proc_param_values 
    where call_id = p_call_id
      and param_id = p_param_id;

    return 0;
end;' language 'plpgsql';

create or replace function dtype_proc_param_value__delete_all (integer)
returns integer as '
declare
  p_call_id           alias for $1;  
begin
    delete from dtype_proc_param_values 
    where call_id = p_call_id;

    return 0;
end;' language 'plpgsql';

