<?xml version="1.0"?>
<queryset>

<fullquery name="dtype::form::get_id.get_form_id"> 
	<querytext>
      select form_id 
        from dtype_form_type_map
       where form = :form
         and object_type = :object_type
	</querytext>
</fullquery>

<fullquery name="dtype::form::get.get_form"> 
	<querytext>
      select form,
             object_type
        from dtype_form_type_map
       where form_id = :form_id
	</querytext>
</fullquery>

<fullquery name="dtype::form::get_root_element_id.get_element_id"> 
	<querytext>
      select element_id 
        from dtype_elements e
             join dtype_forms f using (form_id)
       where f.form_id = :form_id
         and e.parent_id is null
	</querytext>
</fullquery>

<fullquery name="dtype::element::get.select_element_metadata"> 
	<querytext>

      select e.element_id,
             e.parent_id,
             e.name,
             e.form_id,
             tree_level(e.tree_sortkey) as level,
             e.widget,
             e.custom,
             e.layout_id,
             l.filename,
             l.resource_dir
        from dtype_elements e
             left outer join dtype_layouts l on (e.layout_id = l.layout_id)
       where element_id = :element_id
	</querytext>
</fullquery>

<fullquery name="dtype::layout::get_layout_id.get_layout_id"> 
	<querytext>
      select layout_id 
        from dtype_layouts l
       where l.name = :layout
	</querytext>
</fullquery>

<fullquery name="dtype::form::unmap_type.unmap_type"> 
	<querytext>
      delete from dtype_form_type_map
       where form_id = :form_id
         and object_type = :object_type
	</querytext>
</fullquery>

<fullquery name="dtype::element::unmap_attribute.unmap_attribute"> 
	<querytext>
      delete from dtype_element_attribute_map
       where element_id = :element_id
         and attribute_id = :attribute_id
	</querytext>
</fullquery>

<fullquery name="dtype::form::process.update_content"> 
	<querytext>
      update cr_revisions set content = (select content from cr_revisions where revision_id = :prev_revision_id)
       where revision_id = :revision_id
	</querytext>
</fullquery>

<fullquery name="dtype::form::elements_list.select_form_metadata"> 
	<querytext>
      select de.element_id,
             de.name as element,
             de.widget,
             de.custom,
             de.parent_id,
             tree_level(de.tree_sortkey) as level,
             del.layout_id as layout_id,
             del.filename as filename,
             del.resource_dir as resource_dir,
             eaa.attribute_id,
             eaa.attribute_name,
             eaa.pretty_name as attribute_pretty_name,
             eaa.object_type as attribute_object_type,
             eaa.datatype as attribute_datatype,
             eaa.default_value as attribute_default_value
        from (select dre.element_id,
                     dre.tree_sortkey
                from dtype_forms df
                     join dtype_elements dre using (form_id)
               where df.form_id = :form_id
                 and dre.parent_id is null) re
             join dtype_elements de on 
                (de.tree_sortkey >= re.tree_sortkey 
                 and de.tree_sortkey <= tree_right(re.tree_sortkey))
             left outer join dtype_layouts del on 
                (de.layout_id = del.layout_id)
             left outer join (
                 dtype_element_attribute_map deam
                 join acs_attributes aa using (attribute_id)
             ) eaa on (de.element_id = eaa.element_id)
        where form_id = :form_id
        order by de.tree_sortkey
	</querytext>
</fullquery>

<fullquery name="dtype::form::element_params_list.select_form_metadata"> 
	<querytext>
      select dpv.value_id,
             de.element_id,
             dpp.param_id,
             dpp.name,
             dpp.param_type,
             dpv.param_source,
             dpp.is_required,
             dpp.default_value,
             dpv.value
        from (select dre.element_id,
                     dre.tree_sortkey
                from dtype_forms df
                     join dtype_elements dre using (form_id)
               where df.form_id = :form_id
                 and dre.parent_id is null) re
             join dtype_elements de on 
                (de.tree_sortkey >= re.tree_sortkey 
                 and de.tree_sortkey <= tree_right(re.tree_sortkey))
             join dtype_proc_param_values dpv on 
                (dpv.call_id = de.element_id)
             join dtype_proc_params dpp using (param_id)
       where dpp.proc = 'template::element::create'
    order by de.element_id
	</querytext>
</fullquery>

<fullquery name="dtype::form::widget_templates.select_widget_templates"> 
	<querytext>
      select template_id,
             name,
             pretty_name,
             datatype,
             widget
        from dtype_widget_templates wt
	</querytext>
</fullquery>

<fullquery name="dtype::form::widget_template.select_widget_template">
	<querytext>
      select template_id,
             name,
             pretty_name,
             datatype,
             widget
        from dtype_widget_templates wt
       where name = :template 
	</querytext>
</fullquery>

<fullquery name="dtype::form::widget_template_params.select_widget_template_params">
	<querytext>
      select wp.widget,
             wp.param,
             wp.is_required,
             wp.is_html,
             wp.default_value,
             wtp.template_id,
             wtp.param_id,
             wtp.param_type,
             wtp.param_source,
             wtp.value
        from dtype_widget_template_params wtp,
             dtype_widget_templates wt,
             dtype_widget_params wp
       where wtp.template_id = wt.template_id
         and wtp.param_id = wp.param_id
         and wt.name = :template
	</querytext>
</fullquery>

<fullquery name="dtype::form::process.get_revision_ids">
	<querytext>

	select revision_id
    from cr_revisions,
         acs_objects
   where revision_id = object_id
     and item_id = :item_id
order by creation_date desc

	</querytext>
</fullquery>

<fullquery name="dtype::element::create_or_replace_parameter.param_exists">
	<querytext>

      select value_id 
        from dtype_proc_params dp, dtype_proc_param_values dpv 
       where call_id=:element_id 
         and dp.param_id=dpv.param_id 
         and dp.name=:param 
         and dp.proc='template::element::create'

	</querytext>
</fullquery>

<fullquery name="dtype::element::create_or_replace_parameter.update_param">
	<querytext>

      update dtype_proc_param_values 
         set value=:value, 
             source=:source 
       where value_id=:value_id

	</querytext>
</fullquery>

</queryset>
